@@ -2,6 +2,7 @@
 
 # By Carles Mateo https://blog.carlesmateo.com
 # 2021-02-20
+# v. 0.4 Last modified 2021-06-27 15:58 Irish time
 # cmemgzip.py Compresses files in memory, deletes the original, and writes the .gz compressed file.
 # You need to have enough RAM Memory to read the file.
 #
@@ -9,6 +10,7 @@
 import gzip
 import os
 import sys
+import glob
 import datetime
 import time
 import platform
@@ -67,6 +69,29 @@ class FileUtils:
     def test_helper(self):
         pass
 
+    def get_all_files_or_directories_with_mask(self, s_mask):
+        """
+        Get all files matching a given mask or the directories.
+        Example mask: '/proc/[0-9]*/' will return the directories that start from a number.
+        Example mask: '/root/file*.txt'. This mask will return any file in the root directory,
+                      which name starts with 'file' and ends in '.txt'.
+        :param s_mask: The mask to use for gathering the files. Should contain entire file path.
+        :type s_mask: str
+        :return: A boolean indicating success, An Array of files matching the mask
+        :rtype boolean, list
+        """
+        a_files = []
+        b_success = True
+        try:
+            self.test_helper()
+
+            for s_filename in glob.glob(s_mask):
+                a_files.append(s_filename)
+        except IOError:
+            b_success = False
+
+        return b_success, a_files
+
     def delete(self, s_file):
         """
         This method deletes a given file
@@ -457,7 +482,7 @@ class ArgsUtils:
         return a_result
 
 #
-# Processes Utils
+# Python Utils
 #
 # Author: Carles Mateo
 # Creation Date: 2014-11-11 18:18 Barcelona
@@ -719,7 +744,7 @@ class ScreenUtils:
 
 class Cmemgzip:
 
-    VERSION = "0.4.3"
+    VERSION = "0.4.4"
 
     def __init__(self, o_fileutils, o_stringutils, o_datetime, o_argutils, o_screenutils=ScreenUtils(b_support_colors=True), o_pythonutils=PythonUtils()):
         self.o_fileutils = o_fileutils
@@ -758,7 +783,7 @@ class Cmemgzip:
         """
 
         # Get the Filename and Basic Parameters
-        b_simulate, i_mem_mb, s_filename = self.validate_parameters_or_exit()
+        b_simulate, i_mem_mb, s_filename, a_files = self.validate_parameters_or_exit()
 
         print(self.o_screenutils.color_title("cmemgzip.py v." + Cmemgzip.VERSION))
         # Python 2 requires ("") otherwise it prints ()
@@ -774,13 +799,44 @@ class Cmemgzip:
             self.d_p("Running in Simulate / Dry-Run mode. No file will be deleted or written.")
             print("")
 
-        self.compress(s_filename, b_simulate, i_mem_mb)
+        # Check for expanded files. If they sent as parameter "something*" with the double quotes we prevent Bash Expeansion.
+        if "*" in s_filename:
+            self.d_p("Selected to work with a file mask: " + s_filename)
+            b_success, a_files = self.o_fileutils.get_all_files_or_directories_with_mask(s_mask=s_filename)
+            if b_success is False:
+                self.o_screenutils.perror("Problem accessing the files list with mask: " + s_filename)
+                self.exit_app("Review the file mask and permissions", i_error_code=1)
+
+            if len(a_files) > 0:
+                self.d_p("Found " + str(len(a_files)) + " files matching the criteria. Processing...")
+                s_filenames = ", ".join(a_files)
+                self.d_p("List of file to process:\n" + self.o_screenutils.color_label(s_filenames))
+            else:
+                self.o_screenutils.perror("No files found with mask: " + s_filename)
+        else:
+            if len(a_files) > 1:
+                self.d_p("Selected to work with a several files: " + self.o_screenutils.color_label(str(len(a_files))) + " files")
+                s_filenames = ", ".join(a_files)
+                self.d_p("List of file to process:\n" + self.o_screenutils.color_label(s_filenames))
+            elif len(a_files) == 1:
+                a_files = [s_filename]
+
+        for s_file in a_files:
+            b_ends_with_compressed = False
+            for s_ending in [".gz", ".gzip", ".zip", ".bzip", ".bzip2", ".rar", ".xz"]:
+                if s_file.endswith(s_ending) is True:
+                    b_ends_with_compressed = True
+                    break
+            if b_ends_with_compressed is True:
+                self.o_screenutils.perror("We don't compress .gz files. Skipping: " + self.o_screenutils.color_label(s_file))
+            else:
+                self.compress(s_file, b_simulate, i_mem_mb)
 
     def validate_parameters_or_exit(self):
         """
         Validate the input parameters or exit if they are wrong.
 
-        :return: b_simulate, i_mem_mb, s_filename
+        :return: b_simulate, i_mem_mb, s_filename, a_files for the rest of the files
         """
 
         b_black, s_value_black = self.o_argutils.get_arg_from_list(["-b", "--black-and-white"])
@@ -802,7 +858,7 @@ class Cmemgzip:
 
         b_simulate, s_value = self.o_argutils.get_arg_from_list(["-s", "--simulate"])
 
-        return b_simulate, i_mem_mb, s_filename
+        return b_simulate, i_mem_mb, s_filename, a_files
 
     def get_parameter_m(self):
         """
@@ -850,6 +906,13 @@ class Cmemgzip:
         print(s_datetime + " " + s_text)
 
     def compress(self, s_file, b_simulate=False, i_mem_mb=0):
+        """
+
+        :param s_file:
+        :param b_simulate:
+        :param i_mem_mb:
+        :return: i_code Integer indicating what happened with the compressiong of that file
+        """
 
         s_compressed_filename = s_file + ".gz"
 
@@ -861,7 +924,9 @@ class Cmemgzip:
                     self.o_screenutils.color_label(s_biggest_suggested) + " (" + s_filesize_in_bytes + " bytes)"
         self.d_p(s_message)
 
-        self.verify_file_size_min_value_or_exit(i_filesize)
+        if self.is_file_size_min_value(i_filesize) is False:
+            self.o_screenutils.perror("I will not attempt to compress a file less than 100 bytes! Use gzip for that")
+            return 10
 
         self.verifiy_destination_does_not_exist_with_data_or_exit(i_filesize, s_compressed_filename)
 
@@ -887,7 +952,9 @@ class Cmemgzip:
         self.verify_compressed_size_or_exit(i_bytes_read=i_bytes_read, i_bytes_compressed=i_bytes_compressed)
 
         if b_simulate is True:
-            self.exit_app("Running in simulation code. Exiting now.", i_error_code=0)
+            # self.exit_app("Running in simulation mode. Exiting now.", i_error_code=0)
+            self.d_p("Running in simulation mode. Skipping deletion and write of the compressed file.")
+            return 0
 
         print("Attempting to create the gzip file empty to ensure write permissions")
         by_empty = bytes()
@@ -922,6 +989,8 @@ class Cmemgzip:
 
         self.d_p(self.o_screenutils.color_ok("Write verification completed."))
 
+        return 0
+
     def compress_loading_file_completely_in_memory(self, i_filesize, s_file, s_filesize_in_bytes):
         """
         Compress the file completely in memory, loading all of it in memory.
@@ -1000,6 +1069,18 @@ class Cmemgzip:
 
         return True
 
+    def is_file_size_min_value(self, i_filesize):
+        """
+        Check if the file has a minimum size
+        :param i_filesize: Size in bytes
+        :return: booelan
+        """
+        if i_filesize < 100:
+            return False
+
+        return True
+
+
     def verify_access_and_get_filesize_or_exit(self, s_file):
         """
         Will get the file size and if it's unable, will exit
